@@ -22,7 +22,7 @@ var startDebug = function(port,cb) {
 }
 
 var showSmallQrcode = function(string) {
-	qrcode.generate(entryWs, {small: true});
+	qrcode.generate(string, {small: true});
 }
 
 commander
